'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.assertDispatchedActions = exports.unrollActions = exports.getDispatchedActions = undefined;

var _lodash = require('lodash.find');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.flattendeep');

var _lodash4 = _interopRequireDefault(_lodash3);

var _utils = require('../utils');

var _mockStore = require('../mockStore');

var _mockStore2 = _interopRequireDefault(_mockStore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getDispatchedActions(initialState, action) {
  return new Promise(function (resolve, reject) {
    var store = (0, _mockStore2.default)()(initialState);
    var dispatchResult = store.dispatch(action);

    if (dispatchResult instanceof Promise) {
      dispatchResult.then(function () {
        resolve(store.getActions());
      }).catch(function (result) {
        reject(result);
      });
    } else {
      resolve(store.getActions());
    }
  });
}

function unrollActions(initialState, expectedActions) {
  var promises = [];
  var actions = (0, _utils.toArray)(expectedActions);

  for (var index = 0; index < actions.length; index++) {
    promises.push(getDispatchedActions(initialState, actions[index]));
  }

  return Promise.all(promises).then(function (resultActions) {
    return (0, _lodash4.default)(resultActions);
  });
}

function assertDispatchedActions(dispatched, expected) {
  for (var index = 0; index < expected.length; index++) {
    if (!(0, _lodash2.default)(dispatched, expected[index])) {
      throw new Error('Expected action ' + JSON.stringify(expected[index]) + ' was not dispatched.\n' + ('Actual dispatched actions: ' + JSON.stringify(dispatched)));
    }
  }
}

exports.getDispatchedActions = getDispatchedActions;
exports.unrollActions = unrollActions;
exports.assertDispatchedActions = assertDispatchedActions;