'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toDispatchActionsWithState = undefined;

var _utils = require('../utils');

var _actionUtils = require('./actionUtils');

function toDispatchActionsWithState(initialState, actionUnderTest, expectedActions, done, fail) {
  if (!(0, _utils.isFunction)(actionUnderTest) && !(0, _utils.isObject)(actionUnderTest)) {
    throw new Error('The "actualAction" argument must be a function or object');
  }

  if (!(0, _utils.isFunction)(expectedActions) && !(0, _utils.isObject)(expectedActions) && !Array.isArray(expectedActions)) {
    throw new Error('The "expectedActions" argument must be ' + 'an action creator function or an action object or an array of them');
  }

  return (0, _actionUtils.getDispatchedActions)(initialState, actionUnderTest).then(function (dispatchedActions) {
    return (0, _actionUtils.unrollActions)(initialState, expectedActions).then(function (expectedUnrolledActions) {
      (0, _actionUtils.assertDispatchedActions)(dispatchedActions, expectedUnrolledActions);

      if ((0, _utils.isFunction)(done)) {
        done();
      }
    });
  }).catch(function (err) {
    if ((0, _utils.isFunction)(fail)) {
      fail(err);
      return;
    } else if ((0, _utils.isFunction)(done)) {
      done(err);
      return;
    }
    throw new Error(JSON.stringify(err));
  });
}

exports.toDispatchActionsWithState = toDispatchActionsWithState;